package config

import (
	"io/ioutil"

	"gopkg.in/yaml.v2"
)

type Config struct {
	websocket Websocket `yaml:"websocket"`
	grpc      GRPC      `yaml:"grpc"`
}

type Websocket struct {
	writeTimeout    int8  `yaml:"writeTimeout"`
	readTimeout     int8  `yaml:"readTimeout"`
	pongTimeout     int8  `yaml:"pongTimeout"`
	pingTimeout     int8  `yaml:"pingTimeout"`
	maxMessageSize  int64 `yaml:"maxMessageSize"`
	readBufferSize  int   `yaml:"readBufferSize"`
	writeBufferSize int   `yaml:"writeBufferSize"`
}

type GRPC struct {
	host string `yaml:"host"`
	port int16  `yaml:"port"`
	tls  bool   `yaml:"tls"`
}

func LoadConfig(filename string) (*Config, error) {
	bytes, err := ioutil.ReadFile(filename)
	if err != nil {
		return nil, err
	}
	c := new(Config)
	err = yaml.Unmarshal(bytes, &c)
	if err != nil {
		return nil, err
	}

	return c, nil
}
